@@ -93,7 +93,7 @@ searchbyterm <- function(specificepithet = NULL, genus = NULL, family = NULL, or
   args <- compact(list(specificepithet = specificepithet, genus = genus, family = family,
                        order = order, class = class, eventdate = date,
                        mappable = ab(mappable), coordinateuncertaintyinmeters = error,
-                       continent = continent, country = cntry, stateprovince = stateprovince,
+                       continent = continent, country = cntry, stateprovince = sp_paren(stateprovince),
                        county = county, island = island, islandgroup = igroup,
                        institutioncode = inst, occurrenceid = id, catalognumber = catalognumber,
                        recordedby = collector, type = type, hastypestatus = hastypestatus,
@@ -102,6 +102,18 @@ searchbyterm <- function(specificepithet = NULL, genus = NULL, family = NULL, or
   vertwrapper(fxn = "searchbyterm", args = args, lim = limit, compact = compact, verbose = verbose, ...)
 }
 
+sp_paren <- function(x) {
+  if (!is.null(x)) {
+    if (grepl("\\sAND\\s|\\sOR\\s|\\sNOT\\s", x)) {
+      sprintf("(%s)", x)
+    } else {
+      x
+    }
+  } else {
+    NULL
+  }
+}
+
 ab <- function(x){
   if (is.null(x)) {
     NULL
